==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/waf/v20180125/models/DescribeUserClbWafRegionsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.waf.v20180125.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeUserClbWafRegionsResponse extends AbstractModel{

    /**
    * 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Data")
    @Expose
    private String [] Data;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Data 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String [] getData() {
        return this.Data;
    }

    /**
     * Set 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
     * @param Data 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setData(String [] Data) {
        this.Data = Data;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeUserClbWafRegionsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeUserClbWafRegionsResponse(DescribeUserClbWafRegionsResponse source) {
        if (source.Data != null) {
            this.Data = new String[source.Data.length];
            for (int i = 0; i < source.Data.length; i++) {
                this.Data[i] = new String(source.Data[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "Data.", this.Data);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/waf/v20180125/models/DescribeUserClbWafRegionsResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.waf.v20180125.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeUserClbWafRegionsResponse extends AbstractModel {

    /**
    * 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("Data")
    @Expose
    private String [] Data;

    /**
    * 包含详细属性的地域信息
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("RichDatas")
    @Expose
    private ClbWafRegionItem [] RichDatas;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。 
     * @return Data 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String [] getData() {
        return this.Data;
    }

    /**
     * Set 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
     * @param Data 地域（标准的ap-格式）列表
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setData(String [] Data) {
        this.Data = Data;
    }

    /**
     * Get 包含详细属性的地域信息
注意：此字段可能返回 null，表示取不到有效值。 
     * @return RichDatas 包含详细属性的地域信息
注意：此字段可能返回 null，表示取不到有效值。
     */
    public ClbWafRegionItem [] getRichDatas() {
        return this.RichDatas;
    }

    /**
     * Set 包含详细属性的地域信息
注意：此字段可能返回 null，表示取不到有效值。
     * @param RichDatas 包含详细属性的地域信息
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setRichDatas(ClbWafRegionItem [] RichDatas) {
        this.RichDatas = RichDatas;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public DescribeUserClbWafRegionsResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeUserClbWafRegionsResponse(DescribeUserClbWafRegionsResponse source) {
        if (source.Data != null) {
            this.Data = new String[source.Data.length];
            for (int i = 0; i < source.Data.length; i++) {
                this.Data[i] = new String(source.Data[i]);
            }
        }
        if (source.RichDatas != null) {
            this.RichDatas = new ClbWafRegionItem[source.RichDatas.length];
            for (int i = 0; i < source.RichDatas.length; i++) {
                this.RichDatas[i] = new ClbWafRegionItem(source.RichDatas[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArraySimple(map, prefix + "Data.", this.Data);
        this.setParamArrayObj(map, prefix + "RichDatas.", this.RichDatas);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
